[mlpack-git] master: Rename to Hamerly-type score. Because that's what it is. Although Elkan's algorithm has a type of score that's sort of like this, it's Hamerly's algorithm that only keeps track of the second-closest cluster distance, and that's what we're doing here. (cd1765c)

gitdub at big.cc.gt.atl.ga.us gitdub at big.cc.gt.atl.ga.us
Thu Mar 12 16:01:58 EDT 2015


Repository : https://github.com/mlpack/mlpack

On branch  : master
Link       : https://github.com/mlpack/mlpack/compare/eddd7167d69b6c88b271ef2e51d1c20e13f1acd8...70342dd8e5c17e0c164cfb8189748671e9c0dd44

>---------------------------------------------------------------

commit cd1765c30f17e11804866f437e800b53f1740cba
Author: Ryan Curtin <ryan at ratml.org>
Date:   Thu Jan 15 11:44:58 2015 -0500

    Rename to Hamerly-type score. Because that's what it is. Although Elkan's algorithm has a type of score that's sort of like this, it's Hamerly's algorithm that only keeps track of the second-closest cluster distance, and that's what we're doing here.


>---------------------------------------------------------------

cd1765c30f17e11804866f437e800b53f1740cba
 src/mlpack/methods/kmeans/dual_tree_kmeans_rules.hpp      | 6 +++---
 src/mlpack/methods/kmeans/dual_tree_kmeans_rules_impl.hpp | 2 +-
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/mlpack/methods/kmeans/dual_tree_kmeans_rules_impl.hpp b/src/mlpack/methods/kmeans/dual_tree_kmeans_rules_impl.hpp
index df1b065..15ea586 100644
--- a/src/mlpack/methods/kmeans/dual_tree_kmeans_rules_impl.hpp
+++ b/src/mlpack/methods/kmeans/dual_tree_kmeans_rules_impl.hpp
@@ -206,7 +206,7 @@ bool DualTreeKMeansRules<MetricType, TreeType>::IsDescendantOf(
 }
 
 template<typename MetricType, typename TreeType>
-double DualTreeKMeansRules<MetricType, TreeType>::ElkanOverallTypeScore(
+double DualTreeKMeansRules<MetricType, TreeType>::HamerlyTypeScore(
     TreeType& referenceNode)
 {
   // Does the reference node have an owner?



More information about the mlpack-git mailing list
diff --git a/src/mlpack/methods/kmeans/dual_tree_kmeans_rules.hpp b/src/mlpack/methods/kmeans/dual_tree_kmeans_rules.hpp
index 6049f8e..e47651e 100644
--- a/src/mlpack/methods/kmeans/dual_tree_kmeans_rules.hpp
+++ b/src/mlpack/methods/kmeans/dual_tree_kmeans_rules.hpp
@@ -72,12 +72,12 @@ class DualTreeKMeansRules
       potentialChild) const;
 
   /**
    * See if an Elkan-type overall prune can be performed.  This means that the
    * previous iteration owner _must_ be the owner during this iteration.
    *
    * This is not a function of the query node, so it does not need to be passed.
    */
-  double ElkanOverallTypeScore(TreeType& referenceNode);
+  double HamerlyTypeScore(TreeType& referenceNode);
 
   /**
    * See if an Elkan-type prune can be performed.  If so, return DBL_MAX;
@@ -72,12 +72,12 @@ class DualTreeKMeansRules
 
   /**
-   * See if an Elkan-type overall prune can be performed.  This means that the
-   * previous iteration owner _must_ be the owner during this iteration.
+   * See if a Hamerly-type prune can be performed.  This means that the previous
+   * iteration owner _must_ be the owner during this iteration.
    *
    * This is not a function of the query node, so it does not need to be passed.